==> q3-ui-filemanager-1.24.13.tgz: package/lib/FileListMake/FileListMake.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _iconButton = _interopRequireDefault(require("q3-ui/lib/iconButton"));

var _Form = _interopRequireDefault(require("q3-ui-forms/lib/builders/Form"));

var _TextBase = _interopRequireDefault(require("q3-ui-forms/lib/fields/TextBase"));

var _testUtils = require("react-dom/test-utils");

var _FileListMake = _interopRequireDefault(require("./FileListMake"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

describe('FileListBreadcrumbs', () => {
  it('should add new default path to state', async () => {
    const setState = jest.fn();
    const el = global.mount( /*#__PURE__*/_react.default.createElement(_FileListMake.default, {
      setState: setState,
      state: {
        data: {}
      }
    }));
    (0, _testUtils.act)(() => {
      el.find(_iconButton.default).simulate('click');
    });
    await (0, _testUtils.act)(async () => {
      el.update();
      el.find(_Form.default).props().onSubmit({
        name: 'req'
      });
    });
    expect(setState).toHaveBeenCalledWith({
      data: {
        req: {
          default: []
        }
      }
    });
  });
  it('should disallow duplicate paths', async () => {
    const el = global.mount( /*#__PURE__*/_react.default.createElement(_FileListMake.default, {
      setState: jest.fn(),
      state: {
        data: {
          foo: {
            default: []
          }
        }
      }
    }));
    (0, _testUtils.act)(() => {
      el.find(_iconButton.default).simulate('click');
    });
    await (0, _testUtils.act)(async () => {
      el.update();
      el.find(_TextBase.default).props().onChange({
        target: {
          value: 'foo'
        }
      });
    });
    await (0, _testUtils.act)(async () => {
      el.update();
      expect(el.find(_TextBase.default).props()).toHaveProperty('error', true);
    });
  });
});

==> q3-ui-filemanager-3.1.0.tgz: package/lib/FileListMake/FileListMake.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _iconButton = _interopRequireDefault(require("q3-ui/lib/iconButton"));

var _Form = _interopRequireDefault(require("q3-ui-forms/lib/builders/Form"));

var _TextBase = _interopRequireDefault(require("q3-ui-forms/lib/fields/TextBase"));

var _testUtils = require("react-dom/test-utils");

var _FileListMake = _interopRequireDefault(require("./FileListMake"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

const clickIconButton = el => {
  (0, _testUtils.act)(() => {
    el.find(_iconButton.default).prop('buttonProps').onClick({
      preventDefault: jest.fn(),
      target: {
        name: 'Test'
      }
    });
  });
};

describe('FileListBreadcrumbs', () => {
  it('should add new default path to state', async () => {
    const setState = jest.fn();
    const el = global.mount( /*#__PURE__*/_react.default.createElement(_FileListMake.default, {
      setState: setState,
      state: {
        data: {}
      }
    }));
    clickIconButton(el);
    await (0, _testUtils.act)(async () => {
      el.update();
      el.find(_Form.default).props().onSubmit({
        name: 'req'
      });
    });
    expect(setState).toHaveBeenCalledWith({
      data: {
        req: {
          default: []
        }
      }
    });
  });
  it('should disallow duplicate paths', async () => {
    const el = global.mount( /*#__PURE__*/_react.default.createElement(_FileListMake.default, {
      setState: jest.fn(),
      state: {
        data: {
          foo: {
            default: []
          }
        }
      }
    }));
    clickIconButton(el);
    await (0, _testUtils.act)(async () => {
      el.update();
      el.find(_TextBase.default).props().onChange({
        target: {
          value: 'foo'
        }
      });
    });
    await (0, _testUtils.act)(async () => {
      el.update();
      expect(el.find(_TextBase.default).props()).toHaveProperty('error', true);
    });
  });
});
